@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sculpture-themes" "1.7.3"
+(define-package "sculpture-themes" "1.8"
   "Themes with vivid colors."
   '((emacs "26.1"))
   :url "https://github.com/precompute/sculpture-theme"
-  :commit "ce17fba2d12775e9596386b237158b8ca531a186"
-  :revdesc "ce17fba2d127"
+  :commit "247acbd9ef392596ebd84ea5b8e50ca9be9d8ea5"
+  :revdesc "247acbd9ef39"
   :authors '(("Precompute" . "git@precompute.net"))
   :maintainers '(("Precompute" . "git@precompute.net")))
